"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isTextMessageEvent = exports.isMessageEvent = exports.isJoinEvent = exports.isCreateEvent = void 0;
const MatrixMessage_1 = require("../models/MatrixMessage");
/**
 * Check if an event is a create event
 *
 * @param event MatrixStateEvent
 */
const isCreateEvent = (event) => event.type === 'm.room.create' && event.content instanceof Object && 'creator' in event.content;
exports.isCreateEvent = isCreateEvent;
/**
 * Check if an event is a join event
 *
 * @param event MatrixStateEvent
 */
const isJoinEvent = (event) => event.type === 'm.room.member' &&
    event.content instanceof Object &&
    'membership' in event.content &&
    // eslint-disable-next-line dot-notation
    event.content['membership'] === 'join';
exports.isJoinEvent = isJoinEvent;
/**
 * Check if an event is a message event
 *
 * @param event MatrixStateEvent
 */
const isMessageEvent = (event) => event.type === 'm.room.message';
exports.isMessageEvent = isMessageEvent;
/**
 * Check if an event is a text message event
 *
 * @param event MatrixStateEvent
 */
const isTextMessageEvent = (event) => (0, exports.isMessageEvent)(event) &&
    event.content instanceof Object &&
    'msgtype' in event.content &&
    // eslint-disable-next-line dot-notation
    event.content['msgtype'] === MatrixMessage_1.MatrixMessageType.TEXT;
exports.isTextMessageEvent = isTextMessageEvent;
//# sourceMappingURL=events.js.map