import { MatrixClientEvent, MatrixClientEventType, MatrixClientEventMessageContent } from '../matrix-client/models/MatrixClientEvent';
import { Storage, P2PPairingRequest, ExtendedP2PPairingResponse, P2PPairingResponse, NodeDistributions } from '@airgap/beacon-types';
import { CommunicationClient } from '@airgap/beacon-core';
import { ExposedPromise } from '@airgap/beacon-utils';
import { KeyPair } from '@stablelib/ed25519';
interface BeaconInfoResponse {
    region: string;
    known_servers: string[];
    timestamp: number;
}
/**
 * @internalapi
 */
export declare class P2PCommunicationClient extends CommunicationClient {
    private readonly name;
    readonly replicationCount: number;
    private readonly storage;
    private readonly iconUrl?;
    private readonly appUrl?;
    private client;
    private initialEvent;
    private initialListener;
    private selectedRegion?;
    private readonly ENABLED_RELAY_SERVERS;
    relayServer: ExposedPromise<{
        server: string;
        timestamp: number;
        localTimestamp: number;
    }> | undefined;
    private readonly activeListeners;
    private readonly ignoredRooms;
    private loginCounter;
    constructor(name: string, keyPair: KeyPair, replicationCount: number, storage: Storage, matrixNodes?: NodeDistributions, iconUrl?: string | undefined, appUrl?: string | undefined);
    getPairingRequestInfo(): Promise<P2PPairingRequest>;
    getPairingResponseInfo(request: P2PPairingRequest): Promise<P2PPairingResponse>;
    /**
     * To get the fastest region, we can't simply do one request, because sometimes,
     * DNS and SSL handshakes make "faster" connections slower. So we need to do 2 requests
     * and check which request was the fastest after 1s.
     */
    findBestRegionAndGetServer(): Promise<{
        server: string;
        timestamp: number;
    } | undefined>;
    getRelayServer(): Promise<{
        server: string;
        timestamp: number;
    }>;
    getBeaconInfo(server: string): Promise<BeaconInfoResponse>;
    tryJoinRooms(roomId: string, retry?: number): Promise<void>;
    start(): Promise<void>;
    stop(): Promise<void>;
    reset(): Promise<void>;
    listenForEncryptedMessage(senderPublicKey: string, messageCallback: (message: string) => void): Promise<void>;
    unsubscribeFromEncryptedMessage(senderPublicKey: string): Promise<void>;
    unsubscribeFromEncryptedMessages(): Promise<void>;
    sendMessage(message: string, peer: P2PPairingRequest | ExtendedP2PPairingResponse): Promise<void>;
    updatePeerRoom(sender: string, roomId: string): Promise<void>;
    deleteRoomIdFromRooms(roomId: string): Promise<void>;
    listenForChannelOpening(messageCallback: (pairingResponse: ExtendedP2PPairingResponse) => void): Promise<void>;
    waitForJoin(roomId: string, retry?: number): Promise<void>;
    sendPairingResponse(pairingRequest: P2PPairingRequest): Promise<void>;
    isTextMessage(content: MatrixClientEventMessageContent<any>): content is MatrixClientEventMessageContent<string>;
    updateRelayServer(sender: string): Promise<void>;
    isChannelOpenMessage(content: MatrixClientEventMessageContent<string>): Promise<boolean>;
    isSender(event: MatrixClientEvent<MatrixClientEventType.MESSAGE>, senderPublicKey: string): Promise<boolean>;
    private generateNewKeyPair;
    private getRelevantRoom;
    private getRelevantJoinedRoom;
}
export {};
